# PiReplay

Capture and instantly replay the last moments by using a web application controlling a [Raspberry Pi](https://www.raspberrypi.com) with a camera.

Python Package `pireplay` CLI (managed using [Poetry](https://python-poetry.org/))

**Note**: please take a look at the project's GitHub repository **<https://github.com/gruvw/pireplay>**.

## Installation

- Install by running: `sudo pip install pireplay`
<!-- TODO sudo -E and simlink -->
- CLI Usage: `pireplay --help`

**Note**: this progam is only intended to run on a RaspberryPi using a camera module.
